model_enet: model_enet

View source: R/model_enet.R

model_enetR Documentation

model_enet

Description

Function to model elastic net selection process on a given dataframe

Arguments

data

a dataframe containing an outcome variable to be permuted (usually coming from nested bootstrap data)

outcome

the outcome as a string (i.e. "y")

type

model type, either "linear" or "logistic"


stabiliser documentation built on March 9, 2026, 5:08 p.m.