simulate_data_re_glmer: simulate_data_re_glmer

simulate_data_re_glmerR Documentation

simulate_data_re_glmer

Description

Simulate a dataset where some variables are associated with the outcome and some are unk

Usage

simulate_glmer_re_data(
  n_subjects = 100,
  obs_per_subject = 10,
  n_signal = 2,
  n_noise = 3,
  beta0 = -1,
  beta_signal = NULL,
  sigma_u = 1
)

Arguments

n_subjects

The number of individual subjects, e.g. participations

obs_per_subject

The number of observations per subject

n_signal

The number of causal predictors

n_noise

The number of junk predictors

beta0

Intercept

beta_signal

signal size for causal parameters

sigma_u

standard deviation for random intercepts

Value

A simulated dataset with a clustered outcome suitable for random effects analysis with a binary outcome


stabiliser documentation built on March 9, 2026, 5:08 p.m.