Function to calculate stability of variables' association with an outcome for a given model over a number of bootstrap repeats using clustered data.
A list containing a table of variable stabilities and a numeric permutation threshold.
A dataframe containing an outcome variable to be permuted.
The outcome as a string (i.e. "y").
The variable name determining level 2 status as a string (i.e., "level_2_column_name").
The number of variables to filter for final model (Default = 50).
The number of bootstrap samples. Default is "auto" which selects number based on dataframe size.
The number of times to be permuted per repeat. Default is "auto" which selects number based on dataframe size.
The number of times to repeat each set of permutations. Default is 20.
Normalise numeric variables (TRUE/FALSE)
Create dummy variables for factors/characters (TRUE/FALSE)
Impute missing data (TRUE/FALSE)