| stabiliser | R Documentation |
This package uses bootstrap resampling and an objective selection stability threshold to provide a robust method of selecting variables truly associated with an outcome.
Robert Hyde robert.hyde4@nottingham.ac.uk
Eliana Lima
Matthew Barden
Martin Green
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.