| simulate_data_re_glmer | R Documentation |
Simulate a dataset where some variables are associated with the outcome and some are unk
simulate_glmer_re_data(
n_subjects = 100,
obs_per_subject = 10,
n_signal = 2,
n_noise = 3,
beta0 = -1,
beta_signal = NULL,
sigma_u = 1
)
n_subjects |
The number of individual subjects, e.g. participations |
obs_per_subject |
The number of observations per subject |
n_signal |
The number of causal predictors |
n_noise |
The number of junk predictors |
beta0 |
Intercept |
beta_signal |
signal size for causal parameters |
sigma_u |
standard deviation for random intercepts |
A simulated dataset with a clustered outcome suitable for random effects analysis with a binary outcome
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.